﻿using RimWorld;
using System.Collections.Generic;
using Verse;

namespace RoomTypesPlus
{
    [StaticConstructorOnStartup]
    public static class RoomTypesPlus
    {
        static RoomTypesPlus()
        {

        }
    }

    // Room role worker for Battery Room
    public class RoomRoleWorker_BatteryRoom_RTP : RoomRoleWorker
    {
		public override float GetScore(Room room)
		{
			int num = 0;
			List<Thing> containedAndAdjacentThings = room.ContainedAndAdjacentThings;
			for (int i = 0; i < containedAndAdjacentThings.Count; i++)
			{
				
				Thing thing = containedAndAdjacentThings[i];
				if (thing.def.defName == "Battery")
				{
					num++;
				}
			}
			return (float)num * 8f;
		}
	}

	// Room role worker for Walk-in freezer
	public class RoomRoleWorker_WalkinFreezer_RTP : RoomRoleWorker
	{
		public override float GetScore(Room room)
		{
			int num = 0;
			if (room.Temperature <= 1)
            {
				List<Thing> containedAndAdjacentThings = room.ContainedAndAdjacentThings;
				for (int i = 0; i < containedAndAdjacentThings.Count; i++)
				{
					Thing thing = containedAndAdjacentThings[i];
					if (thing.def.IsNutritionGivingIngestible)
					{
						num++;
					}
				}
				return (float)num * 8f;
			} else
            {
				return 0;
            }
		}
	}

	// Room role worker for Pantry
	public class RoomRoleWorker_Pantry_RTP : RoomRoleWorker
	{
		public override float GetScore(Room room)
		{
			int num = 0;
			bool tempControl = false;
			List<Thing> containedAndAdjacentThings = room.ContainedAndAdjacentThings;
			for (int i = 0; i < containedAndAdjacentThings.Count; i++)
			{
				Thing thing = containedAndAdjacentThings[i];
				if(thing.def.defName == "Cooler" || thing.def.defName == "PassiveCooler" || thing.def.defName == "Heater")
                {
					tempControl = true;
					break;
                }

				if (thing.def.IsNutritionGivingIngestible)
				{
					num++;
				}
			}

			if(!tempControl)
            {
				return (float)num * 8f;
			} else
            {
				return 0;
            }
		}
	}

	// Room role worker for Abattoir
	public class RoomRoleWorker_Abattoir_RTP : RoomRoleWorker
	{
		public override float GetScore(Room room)
		{
			int num = 0;
			bool tempControl = false;
			List<Thing> containedAndAdjacentThings = room.ContainedAndAdjacentThings;
			for (int i = 0; i < containedAndAdjacentThings.Count; i++)
			{
				Thing thing = containedAndAdjacentThings[i];
				if (thing.def.defName == "Cooler" || thing.def.defName == "PassiveCooler")
				{
					tempControl = true;
				}

				if (thing.def.IsMeat)
				{
					num++;
				}
				else if (!thing.def.IsMeat && thing.def.IsNutritionGivingIngestible)
				{
					num = 0;
					break;
				}
			}

			if (!tempControl)
			{
				return 0;
			}
			else
			{
				return (float)num * 8f;
			}
		}
	}

	// Room role worker for Generator room
	public class RoomRoleWorker_GeneratorRoom_RTP : RoomRoleWorker
	{
		public override float GetScore(Room room)
		{
			int num = 0;
			List<Thing> containedAndAdjacentThings = room.ContainedAndAdjacentThings;
			for (int i = 0; i < containedAndAdjacentThings.Count; i++)
			{
				Thing thing = containedAndAdjacentThings[i];
				if (thing.def.category == ThingCategory.Building)
				{
					if(thing.def.defName == "WoodFiredGenerator" || thing.def.defName == "ChemfuelPoweredGenerator")
                    {
						num++;
					}
				}
			}
			return (float)num * 10f;
		}
	}

	// Room role worker for Pod room
	public class RoomRoleWorker_PodRoom_RTP : RoomRoleWorker
	{
		public override float GetScore(Room room)
		{
			int num = 0;
			List<Thing> containedAndAdjacentThings = room.ContainedAndAdjacentThings;
			for (int i = 0; i < containedAndAdjacentThings.Count; i++)
			{
				Thing thing = containedAndAdjacentThings[i];
				if (thing.def.category == ThingCategory.Building)
				{
					if (thing.def.defName == "AncientCryptosleepCasket" || thing.def.defName == "CryptosleepCasket" || thing.def.defName == "BiosculpterPod")
					{
						num++;
					}
				}
			}
			return (float)num * 8f;
		}
	}
}
